pub struct JTypeDebug<'a>(/* private fields */);Expand description
Debug helper struct that ensures that the caller understands the safety of printing/debugging the jtype. Its impossible to construct this type without unsafe code.