JBooleanMutPtr

Trait JBooleanMutPtr 

pub trait JBooleanMutPtr: SealedJBooleanMutPtr { }
Trait for all types that can be used as a mutable boolean pointer for jni. JVM commonly uses this for functions that have an c-style output parameter via a pointer.

Implemented by

  • &mut jboolean
  • * mut jboolean
  • &mut bool
  • * mut bool
  • () -> “null pointer”

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl JBooleanMutPtr for &mut bool

Source

impl JBooleanMutPtr for ()

Source

impl JBooleanMutPtr for *mut bool

Source

impl JBooleanMutPtr for *mut jboolean

Implementors