#[non_exhaustive]pub enum LoadFromJavaHomeFolderError {
AlreadyLoaded,
LoadingSharedObjectFailed {
path: String,
error: Box<dyn Error>,
},
JNICreateJavaVmNotFound {
path: String,
error: Box<dyn Error>,
},
JNIGetCreatedJavaVMsNotFound {
path: String,
error: Box<dyn Error>,
},
UnknownJavaHomeLayout,
IOError(Error),
}Expand description
TODO DOCU
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyLoaded
The dynamic linker has already loaded the jvm.
The dynamic linker failed to load the jvm shared object.
JNICreateJavaVmNotFound
The dynamic linker could not find the JNI_CreateJavaVM symbol in the shared object.
Fields
JNIGetCreatedJavaVMsNotFound
The dynamic linker could not find the JNI_GetCreatedJavaVMs symbol in the shared object.
Fields
UnknownJavaHomeLayout
The layout of the java installation was not recognized.
IOError(Error)
I/O Error while determining the layout of the java installation.