pub trait JBooleanMutPtr: SealedJBooleanMutPtr { }Expand description
Trait for all types that can be used as a mutable boolean pointer for jni. JVM commonly uses this for functions that have an c-style output parameter via a pointer.
Implemented by
&mut jboolean* mut jboolean&mut bool* mut bool()-> “null pointer”
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".